@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -21,6 +21,10 @@
     limitations under the License.
 
 ===============================================================================
+
+**Helper functions to serve specific types of content via Django (e.g. raw
+files, PDFs).**
+
 """
 
 
